summaryrefslogtreecommitdiffstats
path: root/chrome/browser/web_contents_view_win.h
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-16 00:26:30 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-16 00:26:30 +0000
commit4d0bd1045bc0df8daea2a5626e73906cb074631b (patch)
tree6794b895e236b68c2f7de1163dfb1c554646364c /chrome/browser/web_contents_view_win.h
parent7609533b68dcbeaa80bf712dd84726d1da8d3f8a (diff)
downloadchromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.zip
chromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.tar.gz
chromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.tar.bz2
Rename ViewContainer to Container and HWNDViewContainer to ContainerWin.
http://crbug.com/3430 Review URL: http://codereview.chromium.org/7376 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@3441 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/web_contents_view_win.h')
-rw-r--r--chrome/browser/web_contents_view_win.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/web_contents_view_win.h b/chrome/browser/web_contents_view_win.h
index 459dd6e..36bcbe7 100644
--- a/chrome/browser/web_contents_view_win.h
+++ b/chrome/browser/web_contents_view_win.h
@@ -6,7 +6,7 @@
#define CHROME_BROWSER_WEB_CONTENTS_VIEW_WIN_H_
#include "chrome/browser/web_contents_view.h"
-#include "chrome/views/hwnd_view_container.h"
+#include "chrome/views/container_win.h"
class InfoBarView;
class InfoBarMessageView;
@@ -16,7 +16,7 @@ class WebDropTarget;
// Windows-specific implementation of the WebContentsView. It is a HWND that
// contains all of the contents of the tab and associated child views.
class WebContentsViewWin : public WebContentsView,
- public ChromeViews::HWNDViewContainer {
+ public ChromeViews::ContainerWin {
public:
// The corresponding WebContents is passed in the constructor, and manages our
// lifetime. This doesn't need to be the case, but is this way currently
@@ -49,7 +49,7 @@ class WebContentsViewWin : public WebContentsView,
private:
// Windows events ------------------------------------------------------------
// Overrides from HWNDViewContainer.
virtual void OnDestroy();
virtual void OnHScroll(int scroll_type, short position, HWND scrollbar);
virtual void OnMouseLeave();
@@ -49,7 +49,7 @@ class WebContentsViewWin : public WebContentsView,
private:
// Windows events ------------------------------------------------------------
- // Overrides from HWNDViewContainer.
+ // Overrides from ContainerWin.
virtual void OnDestroy();
virtual void OnHScroll(int scroll_type, short position, HWND scrollbar);